package org.jbox2d.callbacks;

import org.jbox2d.common.Color3f;
import org.jbox2d.common.Transform;
import org.jbox2d.common.Vec2;

import anywheresoftware.b4a.BA;
import anywheresoftware.b4a.keywords.constants.Colors;

@BA.ShortName(value="jbDebugDraw")
@BA.Events(values={
		"DrawPoint(Point As jbVec2, RadiusOnScreen As Float, Color As Int)",
		"DrawCircle(Center As jbVec2, Radius As Float, Color As Int)",
		"DrawSolidCircle(Center As jbVec2, Radius As Float, Axis As jbVec2, Color As Int)",
		"DrawSegment(P1 As jbVec2, P2 As jbVec2, Color As Int)",
		"DrawSolidPolygon(Vertices() As jbVec2, vertexCount As Int, Color As Int)",
		"DrawString(X As Float, Y As Float, S As String, Color As Int)",
		"DrawTransform(xf As jbTransform)"
})
public class DebugDrawB4A extends DebugDraw
{
	private BA m_ba;
	private String m_EventPrefix;

	public void Initialize(final BA ba, final String EventPrefix)
	{
		m_ba = ba;
		m_EventPrefix = EventPrefix.toLowerCase(BA.cul) + "_";
	}

	private static int RGB(Color3f color)
	{
		return Colors.RGB((int)(color.x * 255), (int)(color.y * 255), (int)(color.z * 255));
	}

	@Override
	public void drawPoint(Vec2 argPoint, float argRadiusOnScreen, Color3f argColor)
	{
		m_ba.raiseEvent2(this, false, m_EventPrefix + "drawpoint", true, new Object[] { argPoint, argRadiusOnScreen, RGB(argColor) });
	}

	@Override
	public void drawSolidPolygon(Vec2[] vertices, int vertexCount, Color3f color)
	{
		m_ba.raiseEvent2(this, false, m_EventPrefix + "drawsolidpolygon", true, new Object[] { vertices, vertexCount, RGB(color) });
	}

	@Override
	public void drawCircle(Vec2 center, float radius, Color3f color)
	{
		m_ba.raiseEvent2(this, false, m_EventPrefix + "drawcircle", true, new Object[] { center, radius, RGB(color) });
	}

	@Override
	public void drawSolidCircle(Vec2 center, float radius, Vec2 axis, Color3f color)
	{
		m_ba.raiseEvent2(this, false, m_EventPrefix + "drawsolidcircle", true, new Object[] { center, radius, axis, RGB(color) });
	}

	@Override
	public void drawSegment(Vec2 p1, Vec2 p2, Color3f color)
	{
		m_ba.raiseEvent2(this, false, m_EventPrefix + "drawsegment", true, new Object[] { p1, p2, RGB(color) });
	}

	@Override
	public void drawTransform(Transform xf)
	{
		m_ba.raiseEvent2(this, false, m_EventPrefix + "drawtransform", true, new Object[] { xf });
	}

	@Override
	public void drawString(float x, float y, String s, Color3f color)
	{
		m_ba.raiseEvent2(this, false, m_EventPrefix + "drawstring", true, new Object[] { x, y, s, RGB(color) });
	}
}
