/*******************************************************************************
 * Copyright (c) 2013, Daniel Murphy
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 	* Redistributions of source code must retain the above copyright notice,
 * 	  this list of conditions and the following disclaimer.
 * 	* Redistributions in binary form must reproduce the above copyright notice,
 * 	  this list of conditions and the following disclaimer in the documentation
 * 	  and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 ******************************************************************************/
package org.jbox2d.dynamics.joints;

import org.jbox2d.dynamics.Body;
import anywheresoftware.b4a.BA;

/**
 * Joint definitions are used to construct joints.
 * @author Daniel Murphy
 */
@BA.ShortName("jbJointDef")
public class JointDef {

	public JointDef(){
		type = JointType.UNKNOWN;
		userData = null;
		bodyA = null;
		bodyB = null;
		collideConnected = false;
	}
	/**
	 * The joint type is set automatically for concrete joint types.
	 */
	public JointType type;

	//--- CODE B4A -----------------------------------------------------------------------------
	public static JointType JOINTTYPE_UNKNOWN = JointType.UNKNOWN;
	public static JointType JOINTTYPE_REVOLUTE = JointType.REVOLUTE;
	public static JointType JOINTTYPE_PRISMATIC = JointType.PRISMATIC;
	public static JointType JOINTTYPE_DISTANCE = JointType.DISTANCE;
	public static JointType JOINTTYPE_PULLEY = JointType.PULLEY;
	public static JointType JOINTTYPE_MOUSE = JointType.MOUSE;
	public static JointType JOINTTYPE_GEAR = JointType.GEAR;
	public static JointType JOINTTYPE_WHEEL = JointType.WHEEL;
	public static JointType JOINTTYPE_WELD = JointType.WELD;
	public static JointType JOINTTYPE_FRICTION = JointType.FRICTION;
	public static JointType JOINTTYPE_ROPE = JointType.ROPE;
	public static JointType JOINTTYPE_CONSTANT_VOLUME = JointType.CONSTANT_VOLUME;
	//------------------------------------------------------------------------------------------

	/**
	 * Use this to attach application specific data to your joints.
	 */
	public Object userData;

	/**
	 * The first attached body.
	 */
	public Body bodyA;

	/**
	 * The second attached body.
	 */
	public Body bodyB;

	/**
	 * Set this flag to true if the attached bodies should collide.
	 */
	public boolean collideConnected;
}
